@@ -12,8 +12,6 @@
 # This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 # WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
-import json
-
 class McLaren720S:
     """
     Class for converting and storing McLaren 720S GT3 setup from json file
@@ -25,11 +23,11 @@ class McLaren720S:
         self.car = setup["carName"]
         self.carTitle = "McLaren 720S GT3"
         #Tyres
-        self.tyreType = self._getTyreType()
-        self.tyrePressure = self._getTyrePressure()
-        self.tyreToe = self._getTyreToe()
-        self.tyreCamber = self._getTyreCamber()
-        self.tyreCaster = self._getTyreCaster()
+        self.tyreType = self._getTyreType(setup)
+        self.tyrePressure = self._getTyrePressure(setup)
+        self.tyreToe = self._getTyreToe(setup)
+        self.tyreCamber = self._getTyreCamber(setup)
+        self.tyreCaster = self._getTyreCaster(setup)
         #Electronics
         self.tc = setup['basicSetup']['electronics']['tC1']
         self.abs = setup['basicSetup']['electronics']['abs']
@@ -42,11 +40,11 @@ class McLaren720S:
         #Mecanical settings
         self.frontARB = setup['advancedSetup']['mechanicalBalance']['aRBFront']
         self.rearARB = setup['advancedSetup']['mechanicalBalance']['aRBRear']
-        self.wheelRate = self._getWheelRate()
-        self.bumpStopRate = self._getBumpStopRate()
+        self.wheelRate = self._getWheelRate(setup)
+        self.bumpStopRate = self._getBumpStopRate(setup)
         self.bumpStopRange = setup['advancedSetup']['mechanicalBalance']['bumpStopWindow']
         self.brakePower = setup['advancedSetup']['mechanicalBalance']['brakeTorque'] + 80
-        self.brakeBias = self._getBrakeBias()
+        self.brakeBias = self._getBrakeBias(setup)
         self.preload = 20 + setup['advancedSetup']['drivetrain']['preload'] * 10
         #Dampers
         self.bumpSlow = setup['advancedSetup']['dampers']['bumpSlow']
@@ -54,26 +52,26 @@ class McLaren720S:
         self.reboundSlow = setup['advancedSetup']['dampers']['reboundSlow']
         self.reboundFast = setup['advancedSetup']['dampers']['reboundFast']
         #Aero
-        self.rideHeight = self._getRideHeight()
+        self.rideHeight = self._getRideHeight(setup)
         self.frontSpliter = 0
         self.rearWing = setup['advancedSetup']['aeroBalance']['rearWing'] + 1
         self.brakeDucts = setup['advancedSetup']['aeroBalance']['brakeDuct']
 
 
-    def _getTyreType(setup): #Function for returning tyre compound
+    def _getTyreType(self, setup): #Function for returning tyre compound
         if setup['basicSetup']['tyres']['tyreCompound'] == 0:
             return "Dry"
         else:
             return "Wet"
         
-    def _getTyrePressure(setup): #Function returns real tyre pressure numbers
+    def _getTyrePressure(self, setup): #Function returns real tyre pressure numbers
         pressures = []
         for p in setup['basicSetup']['tyres']['tyrePressure']:
             pressures.append(round(20.3 + p * 0.1, 1))
 
         return pressures
         
-    def _getTyreToe(setup): #Function returns list of real toe vaules
+    def _getTyreToe(self, setup): #Function returns list of real toe vaules
         toe = []
         for t in range(0, 2): #Front toe
             toe.append(round(-0.48 + setup['basicSetup']['alignment']['toe'][t] * 0.01, 2))
@@ -83,7 +81,7 @@ class McLaren720S:
 
         return toe
     
-    def _getTyreCamber(setup): #Function return list of real camber values
+    def _getTyreCamber(self, setup): #Function return list of real camber values
         camber = []
         for c in range(0, 2): #Front camber
             camber.append(round(-4 + setup['basicSetup']['alignment']['camber'][c] * 0.1, 1))
@@ -93,7 +91,7 @@ class McLaren720S:
 
         return camber
 
-    def _getTyreCaster(setup): #Function returns list of real caster values
+    def _getTyreCaster(self, setup): #Function returns list of real caster values
         casterValues = [5.3, 5.6, 5.8, 6.0, 6.3, 6.5, 6.8, 7.0, 7.3, 7.5, 7.8, 8.0] #Possible vaules in-game
         caster = []
         caster.append(casterValues[setup['basicSetup']['alignment']['casterLF']])
@@ -101,7 +99,7 @@ class McLaren720S:
 
         return caster
     
-    def _getWheelRate(setup): #Returns list of real wheel rate vaules
+    def _getWheelRate(self, setup): #Returns list of real wheel rate vaules
         rates = []
         for r in range(0, 2): #Front springs
             rates.append(118000 + setup['advancedSetup']['mechanicalBalance']['wheelRate'][r] * 16000)
@@ -111,17 +109,17 @@ class McLaren720S:
 
         return rates
     
-    def _getBumpStopRate(setup): #Returns list of real bumpstop rates
+    def _getBumpStopRate(self, setup): #Returns list of real bumpstop rates
         rates = []
         for r in setup['advancedSetup']['mechanicalBalance']['bumpStopRateUp']:
             rates.append(300 + r * 100)
 
         return rates
     
-    def _getBrakeBias(setup): #Returns real brake bias value in %
+    def _getBrakeBias(self, setup): #Returns real brake bias value in %
         return (47.0 + setup['advancedSetup']['mechanicalBalance']['brakeBias'] * 0.2)
     
-    def _getRideHeight(setup): #Returns list of real ride height values [front, rear]
+    def _getRideHeight(self, setup): #Returns list of real ride height values [front, rear]
         height = []
         height.append(50 + setup['advancedSetup']['aeroBalance']['rideHeight'][0]) #Front
         height.append(64 + setup['advancedSetup']['aeroBalance']['rideHeight'][2]) #Rear
